#!/sbin/sh

PATH=/usr/bin
PROGNAME=`basename $0`
LISTNAME=""
typeset -i ATTEMPTS=10
typeset -i SECONDS=10
typeset -i NFILES=0

function Usage {
    echo "usage: $PROGNAME -F <filelist> [-a <attempts>] [-t <wait_time>]"
    exit 1
}

# Process command line arguments
set -- `getopt F:a:t: $*`
if [[ $? -ne 0 ]] then
    Usage
fi
while [[ $# -gt 0 ]] do
    case $1 in
        (-F) LISTNAME=$2
             shift 2
             ;;
        (-a) ATTEMPTS=$2
             shift 2
             ;;
        (-t) SECONDS=$2
             shift 2
             ;;
        (--) shift
             break
             ;;
    esac
done
if [[ $LISTNAME = "" ]] then
    Usage
fi

# Read in the list of files to be deleted.
while read NAME ; do
    FILENAMES[NFILES]="$NAME"
    let NFILES=NFILES+1
done < $LISTNAME

# Delete or attempt to delete the files.
typeset -i i
STATUS=more
while [[ $STATUS = more ]] do
    STATUS=none
    let i=0
    while ((i<NFILES)) ; do
        NAME=${FILENAMES[i]}
        if [[ $NAME != "" ]] then
            if [[ -d $NAME ]] then
                rmdir $NAME
            else
                rm -f $NAME
            fi
            if [[ $? -eq 0 ]] then
                FILENAMES[i]=""
            else
                STATUS=more
            fi
        fi
        let i=i+1
    done

    if [[ $STATUS = more ]] then
        # If we have tried to delete the files more than ATTEMPTS times,
        # set STATUS=quit.  Else sleep for a while and try to delete
        # them again.
        let ATTEMPTS=ATTEMPTS-1
        if [[ $ATTEMPTS -eq 0 ]] then
            STATUS=quit
        else
            sleep $SECONDS
        fi
    fi
done

# Put the name of each file that couldn't be deleted into the SD cleanup
# file.  The cleanup file will be processed at the next system reboot.
if [[ $STATUS = quit ]] then
    umask 022
    let i=0
    while ((i<NFILES)) ; do
        NAME=${FILENAMES[i]}
        if [[ $NAME != "" ]] then
            echo $NAME >> /var/adm/sw/cleanupfile
        fi
        let i=i+1
    done
fi

exit 0
